Новости
=======

Версия 0.2.0 (2022-12-24)
-------------------------

* Переключать чекбоксы для книг по сериям, для всех книг автора или все.

* Python 3.11.

Версия 0.1.6 (2021-09-24)
-------------------------

* Поместить файл ``m_librarian.lock`` в общую директорию;
  использовать ``$UID`` в качестве суффикса имени файла
  чтобы иметь возможность запускать ``m_librarian``
  для разных пользователей.

* Улучшение в web-интерфейсе: сделана ссылка на корень.

* GitHub Actions.

* Перестали использовать Travis CI.

* Перестали использовать AppVeyor.

Версия 0.1.5 (2019-02-01)
-------------------------

* Python 3.7.

Версия 0.1.4 (2018-06-11)
-------------------------

* Поиск по названиям книг.

* Показывать список найденных книг с разбивкой по авторам и сериям.

* Конфигурация списка колонок для таблиц авторов и книг.

* Файл конфигурации, все секции и все ключи сделаны необязательными.

* В файле конфигурации подставляются переменные окружения в ключах,
  указывающих пути.

Версия 0.1.3 (2018-05-25)
-------------------------

* Позволить выбрать несколько книг в списке книг автора.

* Позволить скачать несколько книг сразу.

Версия 0.1.2 (2018-05-22)
-------------------------

* Исправлен импорт INPX: сделано декодирование имён файлов в юникод.

Версия 0.1.1 (2018-05-17)
-------------------------

* Импортируются все файлы \*.glst (Flibusta fb2, LibRusEc fb2, non-fb2).

* Файл README.txt конвертирован в README.rst.

* Импортируются новые INP Флибусты (17 полей).

Версия 0.1.0 (2018-04-25)
-------------------------

* Web-интерфейс для поиска авторов, показа списка книг автора,
  загрузки одной книги.

* Программа `ml-web.py` не позволяет запускать два экземпляра.
  Второй экземпляр перенаправляет web-обозреватель на web-интерфейс
  первого экземпляра и прекращает работу.

* Опция `--download-to` в скрипте `ml-search.py` задаёт директорию
  для сохранения книг.
